@@ -60,8 +60,8 @@ use core::{mem, u16, u32, u8};
 ///
 /// struct MySymbolResolver { map: HashMap<u64, String> }
 /// impl SymbolResolver for MySymbolResolver {
-///     fn symbol(&mut self, instruction: &Instruction, operand: u32, instruction_operand: Option<u32>,
-///          address: u64, address_size: u32) -> Option<SymbolResult> {
+///     fn symbol(&mut self, _instruction: &Instruction, _operand: u32, _instruction_operand: Option<u32>,
+///          address: u64, _address_size: u32) -> Option<SymbolResult> {
 ///         if let Some(symbol_string) = self.map.get(&address) {
 ///             // The 'address' arg is the address of the symbol and doesn't have to be identical
 ///             // to the 'address' arg passed to symbol(). If it's different from the input
@@ -485,25 +485,25 @@ impl GasFormatter {
 				} else {
 					flow_control = get_flow_control(instruction);
 					let s = if op_kind == InstrOpKind::NearBranch32 {
-						self.number_formatter.format_u32_zeroes(
+						self.number_formatter.format_u32_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.near_branch32(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						)
 					} else if op_kind == InstrOpKind::NearBranch64 {
-						self.number_formatter.format_u64_zeroes(
+						self.number_formatter.format_u64_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.near_branch64(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						)
 					} else {
-						self.number_formatter.format_u16_zeroes(
+						self.number_formatter.format_u16_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.near_branch16(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						)
 					};
 					output.write_number(
@@ -560,11 +560,11 @@ impl GasFormatter {
 							self.d.options.show_symbol_address(),
 						);
 					} else {
-						let s = self.number_formatter.format_u16_zeroes(
+						let s = self.number_formatter.format_u16_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.far_branch_selector(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						);
 						output.write_number(
 							instruction,
@@ -595,11 +595,11 @@ impl GasFormatter {
 					);
 				} else {
 					flow_control = get_flow_control(instruction);
-					let s = self.number_formatter.format_u16_zeroes(
+					let s = self.number_formatter.format_u16_zeros(
 						&self.d.options,
 						&number_options,
 						instruction.far_branch_selector(),
-						number_options.leading_zeroes,
+						number_options.leading_zeros,
 					);
 					output.write(GasFormatter::IMMEDIATE_VALUE_PREFIX, FormatterTextKind::Operator);
 					output.write_number(
@@ -616,18 +616,18 @@ impl GasFormatter {
 						output.write(" ", FormatterTextKind::Text);
 					}
 					let s = if op_kind == InstrOpKind::FarBranch32 {
-						self.number_formatter.format_u32_zeroes(
+						self.number_formatter.format_u32_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.far_branch32(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						)
 					} else {
-						self.number_formatter.format_u16_zeroes(
+						self.number_formatter.format_u16_zeros(
 							&self.d.options,
 							&number_options,
 							instruction.far_branch16(),
-							number_options.leading_zeroes,
+							number_options.leading_zeros,
 						)
 					};
 					output.write(GasFormatter::IMMEDIATE_VALUE_PREFIX, FormatterTextKind::Operator);
@@ -1140,17 +1140,15 @@ impl GasFormatter {
 						output.write("-", FormatterTextKind::Operator);
 						displ = displ.wrapping_neg();
 					}
-					if number_options.displacement_leading_zeroes {
-						debug_assert!(displ_size <= 8);
-						displ_size = 8;
+					if number_options.displacement_leading_zeros {
+						displ_size = 4;
 					}
 				} else if addr_size == 4 {
 					if number_options.signed_number && (displ as i32) < 0 {
 						output.write("-", FormatterTextKind::Operator);
 						displ = (displ as i32).wrapping_neg() as u32 as i64;
 					}
-					if number_options.displacement_leading_zeroes {
-						debug_assert!(displ_size <= 4);
+					if number_options.displacement_leading_zeros {
 						displ_size = 4;
 					}
 				} else {
@@ -1159,8 +1157,7 @@ impl GasFormatter {
 						output.write("-", FormatterTextKind::Operator);
 						displ = (displ as i16).wrapping_neg() as u16 as i64;
 					}
-					if number_options.displacement_leading_zeroes {
-						debug_assert!(displ_size <= 2);
+					if number_options.displacement_leading_zeros {
 						displ_size = 2;
 					}
 				}
@@ -1170,22 +1167,22 @@ impl GasFormatter {
 
 			let (s, displ_kind) = if displ_size <= 1 && displ as u64 <= u8::MAX as u64 {
 				(
-					self.number_formatter.format_u8(&self.d.options, &number_options, displ as u8),
+					self.number_formatter.format_displ_u8(&self.d.options, &number_options, displ as u8),
 					if is_signed { NumberKind::Int8 } else { NumberKind::UInt8 },
 				)
 			} else if displ_size <= 2 && displ as u64 <= u16::MAX as u64 {
 				(
-					self.number_formatter.format_u16(&self.d.options, &number_options, displ as u16),
+					self.number_formatter.format_displ_u16(&self.d.options, &number_options, displ as u16),
 					if is_signed { NumberKind::Int16 } else { NumberKind::UInt16 },
 				)
 			} else if displ_size <= 4 && displ as u64 <= u32::MAX as u64 {
 				(
-					self.number_formatter.format_u32(&self.d.options, &number_options, displ as u32),
+					self.number_formatter.format_displ_u32(&self.d.options, &number_options, displ as u32),
 					if is_signed { NumberKind::Int32 } else { NumberKind::UInt32 },
 				)
 			} else if displ_size <= 8 {
 				(
-					self.number_formatter.format_u64(&self.d.options, &number_options, displ as u64),
+					self.number_formatter.format_displ_u64(&self.d.options, &number_options, displ as u64),
 					if is_signed { NumberKind::Int64 } else { NumberKind::UInt64 },
 				)
 			} else {
