@@ -5,8 +5,8 @@ use crate::formatter::gas::enums::*;
 use crate::formatter::gas::fmt_utils::can_show_rounding_control;
 use crate::formatter::gas::get_mnemonic_cc;
 use crate::formatter::gas::mem_size_tbl::MEM_SIZE_TBL;
-use crate::formatter::gas::regs::*;
 use crate::formatter::FormatterString;
+use crate::formatter::{r64_to_r32, r_to_r16, REGISTER_ST};
 use crate::iced_constants::IcedConstants;
 use crate::*;
 use alloc::string::String;
@@ -20,16 +20,18 @@ pub(super) struct InstrOpInfo<'a> {
 	pub(super) flags: u16, // InstrOpInfoFlags
 	pub(super) op_count: u8,
 	op_kinds: [InstrOpKind; IcedConstants::MAX_OP_COUNT],
-	op_registers: [u8; IcedConstants::MAX_OP_COUNT],
+	op_registers: [Register; IcedConstants::MAX_OP_COUNT],
 	op_indexes: [i8; IcedConstants::MAX_OP_COUNT],
 }
 
 impl<'a> InstrOpInfo<'a> {
-	#[allow(dead_code)]
-	pub(super) const TEST_REGISTER_BITS: u32 = IcedConstants::REGISTER_BITS;
+	fn to_instr_op_kind(op_kind: OpKind) -> InstrOpKind {
+		// SAFETY: All OpKind values are valid InstrOpKind values
+		unsafe { mem::transmute(op_kind as u8) }
+	}
 
-	pub(super) fn op_register(&self, operand: u32) -> usize {
-		self.op_registers[operand as usize] as usize
+	pub(super) fn op_register(&self, operand: u32) -> Register {
+		self.op_registers[operand as usize]
 	}
 
 	pub(super) fn op_kind(&self, operand: u32) -> InstrOpKind {
@@ -118,7 +120,7 @@ impl<'a> InstrOpInfo<'a> {
 			flags: 0,
 			op_count: 0,
 			op_kinds: [InstrOpKind::default(); IcedConstants::MAX_OP_COUNT],
-			op_registers: [0; IcedConstants::MAX_OP_COUNT],
+			op_registers: [Register::None; IcedConstants::MAX_OP_COUNT],
 			op_indexes: [0; IcedConstants::MAX_OP_COUNT],
 		}
 	}
@@ -131,63 +133,63 @@ impl<'a> InstrOpInfo<'a> {
 		let op_count = instruction.op_count();
 		res.op_count = op_count as u8;
 		if (flags & InstrOpInfoFlags::KEEP_OPERAND_ORDER) != 0 {
-			res.op_kinds[0] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-			res.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-			res.op_kinds[2] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-			res.op_kinds[3] = unsafe { mem::transmute(instruction.op3_kind() as u8) };
-			res.op_kinds[4] = unsafe { mem::transmute(instruction.op4_kind() as u8) };
-			res.op_registers[0] = instruction.op0_register() as u8;
-			res.op_registers[1] = instruction.op1_register() as u8;
-			res.op_registers[2] = instruction.op2_register() as u8;
-			res.op_registers[3] = instruction.op3_register() as u8;
-			res.op_registers[4] = instruction.op4_register() as u8;
+			res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+			res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+			res.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+			res.op_kinds[3] = InstrOpInfo::to_instr_op_kind(instruction.op3_kind());
+			res.op_kinds[4] = InstrOpInfo::to_instr_op_kind(instruction.op4_kind());
+			res.op_registers[0] = instruction.op0_register();
+			res.op_registers[1] = instruction.op1_register();
+			res.op_registers[2] = instruction.op2_register();
+			res.op_registers[3] = instruction.op3_register();
+			res.op_registers[4] = instruction.op4_register();
 		} else {
 			match op_count {
 				0 => {}
 
 				1 => {
-					res.op_kinds[0] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-					res.op_registers[0] = instruction.op0_register() as u8;
+					res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+					res.op_registers[0] = instruction.op0_register();
 				}
 
 				2 => {
-					res.op_kinds[0] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-					res.op_kinds[1] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-					res.op_registers[0] = instruction.op1_register() as u8;
-					res.op_registers[1] = instruction.op0_register() as u8;
+					res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+					res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+					res.op_registers[0] = instruction.op1_register();
+					res.op_registers[1] = instruction.op0_register();
 				}
 
 				3 => {
-					res.op_kinds[0] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-					res.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-					res.op_kinds[2] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-					res.op_registers[0] = instruction.op2_register() as u8;
-					res.op_registers[1] = instruction.op1_register() as u8;
-					res.op_registers[2] = instruction.op0_register() as u8;
+					res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+					res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+					res.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+					res.op_registers[0] = instruction.op2_register();
+					res.op_registers[1] = instruction.op1_register();
+					res.op_registers[2] = instruction.op0_register();
 				}
 
 				4 => {
-					res.op_kinds[0] = unsafe { mem::transmute(instruction.op3_kind() as u8) };
-					res.op_kinds[1] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-					res.op_kinds[2] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-					res.op_kinds[3] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-					res.op_registers[0] = instruction.op3_register() as u8;
-					res.op_registers[1] = instruction.op2_register() as u8;
-					res.op_registers[2] = instruction.op1_register() as u8;
-					res.op_registers[3] = instruction.op0_register() as u8;
+					res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op3_kind());
+					res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+					res.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+					res.op_kinds[3] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+					res.op_registers[0] = instruction.op3_register();
+					res.op_registers[1] = instruction.op2_register();
+					res.op_registers[2] = instruction.op1_register();
+					res.op_registers[3] = instruction.op0_register();
 				}
 
 				5 => {
-					res.op_kinds[0] = unsafe { mem::transmute(instruction.op4_kind() as u8) };
-					res.op_kinds[1] = unsafe { mem::transmute(instruction.op3_kind() as u8) };
-					res.op_kinds[2] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-					res.op_kinds[3] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-					res.op_kinds[4] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-					res.op_registers[0] = instruction.op4_register() as u8;
-					res.op_registers[1] = instruction.op3_register() as u8;
-					res.op_registers[2] = instruction.op2_register() as u8;
-					res.op_registers[3] = instruction.op1_register() as u8;
-					res.op_registers[4] = instruction.op0_register() as u8;
+					res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op4_kind());
+					res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op3_kind());
+					res.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+					res.op_kinds[3] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+					res.op_kinds[4] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+					res.op_registers[0] = instruction.op4_register();
+					res.op_registers[1] = instruction.op3_register();
+					res.op_registers[2] = instruction.op2_register();
+					res.op_registers[3] = instruction.op1_register();
+					res.op_registers[4] = instruction.op0_register();
 				}
 
 				_ => unreachable!(),
@@ -407,10 +409,8 @@ impl InstrInfo for SimpleInstrInfo_nop {
 			const_assert_eq!(InstrOpKind::Register as u32, 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
 			//info.op_kinds[1] = InstrOpKind::Register;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = self.register as u8;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = self.register as u8;
+			info.op_registers[0] = self.register;
+			info.op_registers[1] = self.register;
 			info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_NONE;
 			info.op_indexes[1] = InstrInfoConstants::OP_ACCESS_NONE;
 		}
@@ -440,7 +440,7 @@ impl InstrInfo for SimpleInstrInfo_STIG1 {
 			info.op_count = 1;
 			const_assert_eq!(InstrOpKind::Register as u32, 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
-			info.op_registers[0] = instruction.op1_register() as u8;
+			info.op_registers[0] = instruction.op1_register();
 			info.op_indexes[0] = 1;
 		}
 		info
@@ -469,8 +469,7 @@ impl InstrInfo for SimpleInstrInfo_STi_ST {
 		} else {
 			info = InstrOpInfo::new(&self.mnemonic, instruction, FLAGS);
 			debug_assert_eq!(info.op_registers[0] as u32, Register::ST0 as u32);
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = Registers::REGISTER_ST as u8;
+			info.op_registers[0] = REGISTER_ST;
 		}
 		info
 	}
@@ -491,8 +490,7 @@ impl InstrInfo for SimpleInstrInfo_ST_STi {
 	fn op_info<'a>(&'a self, _options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		let mut info = InstrOpInfo::new(&self.mnemonic, instruction, InstrOpInfoFlags::NONE);
 		debug_assert_eq!(info.op_registers[1] as u32, Register::ST0 as u32);
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[1] = Registers::REGISTER_ST as u8;
+		info.op_registers[1] = REGISTER_ST;
 		info
 	}
 }
@@ -552,11 +550,11 @@ impl InstrInfo for SimpleInstrInfo_maskmovq {
 
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		info.op_count = 2;
-		info.op_kinds[0] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-		info.op_registers[0] = instruction.op2_register() as u8;
+		info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+		info.op_registers[0] = instruction.op2_register();
 		info.op_indexes[0] = 2;
-		info.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-		info.op_registers[1] = instruction.op1_register() as u8;
+		info.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+		info.op_registers[1] = instruction.op1_register();
 		info.op_indexes[1] = 1;
 		if instr_bitness != 0 && instr_bitness != bitness {
 			if bitness == 16 {
@@ -589,14 +587,13 @@ impl InstrInfo for SimpleInstrInfo_pblendvb {
 		info.op_count = 3;
 		const_assert_eq!(InstrOpKind::Register as u32, 0);
 		//info.op_kinds[0] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = Register::XMM0 as u8;
+		info.op_registers[0] = Register::XMM0;
 		info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_READ;
-		info.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+		info.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 		info.op_indexes[1] = 1;
-		info.op_registers[1] = instruction.op1_register() as u8;
-		info.op_kinds[2] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-		info.op_registers[2] = instruction.op0_register() as u8;
+		info.op_registers[1] = instruction.op1_register();
+		info.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+		info.op_registers[2] = instruction.op0_register();
 		info
 	}
 }
@@ -839,18 +836,9 @@ impl InstrInfo for SimpleInstrInfo_Reg16 {
 	fn op_info<'a>(&'a self, options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		let flags = InstrOpInfoFlags::NONE;
 		let mut info = InstrOpInfo::new(get_mnemonic(options, instruction, &self.mnemonic, &self.mnemonic_suffix, flags), instruction, flags);
-		if Register::EAX as u8 <= info.op_registers[0] && info.op_registers[0] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = (info.op_registers[0].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
-		if Register::EAX as u8 <= info.op_registers[1] && info.op_registers[1] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = (info.op_registers[1].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
-		if Register::EAX as u8 <= info.op_registers[2] && info.op_registers[2] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[2] = (info.op_registers[2].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
+		info.op_registers[0] = r_to_r16(info.op_registers[0]);
+		info.op_registers[1] = r_to_r16(info.op_registers[1]);
+		info.op_registers[2] = r_to_r16(info.op_registers[2]);
 		info
 	}
 }
@@ -1338,18 +1326,9 @@ impl InstrInfo for SimpleInstrInfo_Reg32 {
 	fn op_info<'a>(&'a self, _options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		const FLAGS: u32 = InstrOpInfoFlags::NONE;
 		let mut info = InstrOpInfo::new(&self.mnemonic, instruction, FLAGS);
-		if Register::RAX as u8 <= info.op_registers[0] && info.op_registers[0] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = info.op_registers[0].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
-		if Register::RAX as u8 <= info.op_registers[1] && info.op_registers[1] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = info.op_registers[1].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
-		if Register::RAX as u8 <= info.op_registers[2] && info.op_registers[2] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[2] = info.op_registers[2].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
+		info.op_registers[0] = r64_to_r32(info.op_registers[0]);
+		info.op_registers[1] = r64_to_r32(info.op_registers[1]);
+		info.op_registers[2] = r64_to_r32(info.op_registers[2]);
 		info
 	}
 }
