@@ -4,8 +4,8 @@
 use crate::formatter::masm::enums::*;
 use crate::formatter::masm::fmt_utils::show_segment_prefix;
 use crate::formatter::masm::get_mnemonic_cc;
-use crate::formatter::masm::regs::*;
 use crate::formatter::FormatterString;
+use crate::formatter::{r64_to_r32, r_to_r16, REGISTER_ST};
 use crate::iced_constants::IcedConstants;
 use crate::*;
 use alloc::string::String;
@@ -19,16 +19,18 @@ pub(super) struct InstrOpInfo<'a> {
 	pub(super) flags: u16, // InstrOpInfoFlags
 	pub(super) op_count: u8,
 	op_kinds: [InstrOpKind; IcedConstants::MAX_OP_COUNT],
-	op_registers: [u8; IcedConstants::MAX_OP_COUNT],
+	op_registers: [Register; IcedConstants::MAX_OP_COUNT],
 	op_indexes: [i8; IcedConstants::MAX_OP_COUNT],
 }
 
 impl<'a> InstrOpInfo<'a> {
-	#[allow(dead_code)]
-	pub(super) const TEST_REGISTER_BITS: u32 = IcedConstants::REGISTER_BITS;
+	fn to_instr_op_kind(op_kind: OpKind) -> InstrOpKind {
+		// SAFETY: All OpKind values are valid InstrOpKind values
+		unsafe { mem::transmute(op_kind as u8) }
+	}
 
-	pub(super) fn op_register(&self, operand: u32) -> usize {
-		self.op_registers[operand as usize] as usize
+	pub(super) fn op_register(&self, operand: u32) -> Register {
+		self.op_registers[operand as usize]
 	}
 
 	pub(super) fn op_kind(&self, operand: u32) -> InstrOpKind {
@@ -117,7 +119,7 @@ impl<'a> InstrOpInfo<'a> {
 			flags: 0,
 			op_count: 0,
 			op_kinds: [InstrOpKind::default(); IcedConstants::MAX_OP_COUNT],
-			op_registers: [0; IcedConstants::MAX_OP_COUNT],
+			op_registers: [Register::None; IcedConstants::MAX_OP_COUNT],
 			op_indexes: [0; IcedConstants::MAX_OP_COUNT],
 		}
 	}
@@ -127,21 +129,16 @@ impl<'a> InstrOpInfo<'a> {
 
 		const_assert_eq!(IcedConstants::MAX_OP_COUNT, 5);
 		res.flags = flags as u16;
-		res.op_kinds[0] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-		res.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
-		res.op_kinds[2] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
-		res.op_kinds[3] = unsafe { mem::transmute(instruction.op3_kind() as u8) };
-		res.op_kinds[4] = unsafe { mem::transmute(instruction.op4_kind() as u8) };
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		res.op_registers[0] = instruction.op0_register() as u8;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		res.op_registers[1] = instruction.op1_register() as u8;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		res.op_registers[2] = instruction.op2_register() as u8;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		res.op_registers[3] = instruction.op3_register() as u8;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		res.op_registers[4] = instruction.op4_register() as u8;
+		res.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+		res.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
+		res.op_kinds[2] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
+		res.op_kinds[3] = InstrOpInfo::to_instr_op_kind(instruction.op3_kind());
+		res.op_kinds[4] = InstrOpInfo::to_instr_op_kind(instruction.op4_kind());
+		res.op_registers[0] = instruction.op0_register();
+		res.op_registers[1] = instruction.op1_register();
+		res.op_registers[2] = instruction.op2_register();
+		res.op_registers[3] = instruction.op3_register();
+		res.op_registers[4] = instruction.op4_register();
 		let op_count = instruction.op_count();
 		res.op_count = op_count as u8;
 		match op_count {
@@ -496,7 +493,7 @@ impl InstrInfo for SimpleInstrInfo_YA {
 			info = InstrOpInfo::default(&self.mnemonic_args);
 			info.flags = FLAGS as u16;
 			info.op_count = 1;
-			info.op_kinds[0] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
+			info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
 		} else {
 			info = InstrOpInfo::default(&self.mnemonic_no_args);
 			info.flags = FLAGS as u16;
@@ -533,7 +530,7 @@ impl InstrInfo for SimpleInstrInfo_AX {
 			info = InstrOpInfo::default(&self.mnemonic_args);
 			info.flags = FLAGS as u16;
 			info.op_count = 1;
-			info.op_kinds[0] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+			info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 			info.op_indexes[0] = 1;
 		} else {
 			info = InstrOpInfo::default(&self.mnemonic_no_args);
@@ -571,7 +568,7 @@ impl InstrInfo for SimpleInstrInfo_AY {
 			info = InstrOpInfo::default(&self.mnemonic_args);
 			info.flags = FLAGS as u16;
 			info.op_count = 1;
-			info.op_kinds[0] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+			info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 			info.op_indexes[0] = 1;
 		} else {
 			info = InstrOpInfo::default(&self.mnemonic_no_args);
@@ -636,10 +633,8 @@ impl InstrInfo for SimpleInstrInfo_nop {
 			const_assert_eq!(InstrOpKind::Register as u32, 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
 			//info.op_kinds[1] = InstrOpKind::Register;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = self.register as u8;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = self.register as u8;
+			info.op_registers[0] = self.register;
+			info.op_registers[1] = self.register;
 			info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_NONE;
 			info.op_indexes[1] = InstrInfoConstants::OP_ACCESS_NONE;
 			info
@@ -669,8 +664,7 @@ impl InstrInfo for SimpleInstrInfo_STIG1 {
 			info.op_count = 1;
 			const_assert_eq!(InstrOpKind::Register as u32, 0);
 			//info.op_kinds[0] = InstrOpKind::Register;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = instruction.op1_register() as u8;
+			info.op_registers[0] = instruction.op1_register();
 			info.op_indexes[0] = 1;
 		}
 		info
@@ -698,9 +692,8 @@ impl InstrInfo for SimpleInstrInfo_STi_ST {
 			info = InstrOpInfo::default(&self.mnemonic);
 		} else {
 			info = InstrOpInfo::new(&self.mnemonic, instruction, FLAGS);
-			debug_assert_eq!(info.op_registers[1], Register::ST0 as u8);
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = Registers::REGISTER_ST as u8;
+			debug_assert_eq!(info.op_registers[1], Register::ST0);
+			info.op_registers[1] = REGISTER_ST;
 		}
 		info
 	}
@@ -720,9 +713,8 @@ impl SimpleInstrInfo_ST_STi {
 impl InstrInfo for SimpleInstrInfo_ST_STi {
 	fn op_info<'a>(&'a self, _options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		let mut info = InstrOpInfo::new(&self.mnemonic, instruction, InstrOpInfoFlags::NONE);
-		debug_assert_eq!(info.op_registers[0], Register::ST0 as u8);
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = Registers::REGISTER_ST as u8;
+		debug_assert_eq!(info.op_registers[0], Register::ST0);
+		info.op_registers[0] = REGISTER_ST;
 		info
 	}
 }
@@ -746,14 +738,11 @@ impl InstrInfo for SimpleInstrInfo_monitor {
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		info.op_count = 3;
 		info.op_kinds[0] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = self.register1 as u8;
+		info.op_registers[0] = self.register1;
 		info.op_kinds[1] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[1] = self.register2 as u8;
+		info.op_registers[1] = self.register2;
 		info.op_kinds[2] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[2] = self.register3 as u8;
+		info.op_registers[2] = self.register3;
 		info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_READ;
 		info.op_indexes[1] = InstrInfoConstants::OP_ACCESS_READ;
 		info.op_indexes[2] = InstrInfoConstants::OP_ACCESS_READ;
@@ -789,22 +778,16 @@ impl InstrInfo for SimpleInstrInfo_mwait {
 
 		match instruction.code_size() {
 			CodeSize::Code16 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::AX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::ECX as u8;
+				info.op_registers[0] = Register::AX;
+				info.op_registers[1] = Register::ECX;
 			}
 			CodeSize::Code32 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::EAX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::ECX as u8;
+				info.op_registers[0] = Register::EAX;
+				info.op_registers[1] = Register::ECX;
 			}
 			CodeSize::Unknown | CodeSize::Code64 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::RAX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::RCX as u8;
+				info.op_registers[0] = Register::RAX;
+				info.op_registers[1] = Register::RCX;
 			}
 		}
 		info
@@ -835,28 +818,19 @@ impl InstrInfo for SimpleInstrInfo_mwaitx {
 
 		match instruction.code_size() {
 			CodeSize::Code16 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::AX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::ECX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[2] = Register::EBX as u8;
+				info.op_registers[0] = Register::AX;
+				info.op_registers[1] = Register::ECX;
+				info.op_registers[2] = Register::EBX;
 			}
 			CodeSize::Code32 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::EAX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::ECX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[2] = Register::EBX as u8;
+				info.op_registers[0] = Register::EAX;
+				info.op_registers[1] = Register::ECX;
+				info.op_registers[2] = Register::EBX;
 			}
 			CodeSize::Unknown | CodeSize::Code64 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::RAX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[1] = Register::RCX as u8;
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[2] = Register::RBX as u8;
+				info.op_registers[0] = Register::RAX;
+				info.op_registers[1] = Register::RCX;
+				info.op_registers[2] = Register::RBX;
 			}
 		}
 		info
@@ -893,14 +867,12 @@ impl InstrInfo for SimpleInstrInfo_maskmovq {
 			info = InstrOpInfo::default(&self.mnemonic);
 			info.flags = self.flags as u16;
 			info.op_count = 2;
-			info.op_kinds[0] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+			info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 			info.op_indexes[0] = 1;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = instruction.op1_register() as u8;
-			info.op_kinds[1] = unsafe { mem::transmute(instruction.op2_kind() as u8) };
+			info.op_registers[0] = instruction.op1_register();
+			info.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op2_kind());
 			info.op_indexes[1] = 2;
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = instruction.op2_register() as u8;
+			info.op_registers[1] = instruction.op2_register();
 		}
 		info
 	}
@@ -922,16 +894,13 @@ impl InstrInfo for SimpleInstrInfo_pblendvb {
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		debug_assert_eq!(instruction.op_count(), 2);
 		info.op_count = 3;
-		info.op_kinds[0] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = instruction.op0_register() as u8;
-		info.op_kinds[1] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+		info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+		info.op_registers[0] = instruction.op0_register();
+		info.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 		info.op_indexes[1] = 1;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[1] = instruction.op1_register() as u8;
+		info.op_registers[1] = instruction.op1_register();
 		info.op_kinds[2] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[2] = Register::XMM0 as u8;
+		info.op_registers[2] = Register::XMM0;
 		info.op_indexes[2] = InstrInfoConstants::OP_ACCESS_READ;
 		info
 	}
@@ -953,13 +922,11 @@ impl InstrInfo for SimpleInstrInfo_reverse {
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		debug_assert_eq!(instruction.op_count(), 2);
 		info.op_count = 2;
-		info.op_kinds[0] = unsafe { mem::transmute(instruction.op1_kind() as u8) };
+		info.op_kinds[0] = InstrOpInfo::to_instr_op_kind(instruction.op1_kind());
 		info.op_indexes[0] = 1;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = instruction.op1_register() as u8;
-		info.op_kinds[1] = unsafe { mem::transmute(instruction.op0_kind() as u8) };
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[1] = instruction.op0_register() as u8;
+		info.op_registers[0] = instruction.op1_register();
+		info.op_kinds[1] = InstrOpInfo::to_instr_op_kind(instruction.op0_kind());
+		info.op_registers[1] = instruction.op0_register();
 		info
 	}
 }
@@ -1248,18 +1215,9 @@ impl SimpleInstrInfo_Reg16 {
 impl InstrInfo for SimpleInstrInfo_Reg16 {
 	fn op_info<'a>(&'a self, _options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		let mut info = InstrOpInfo::new(&self.mnemonic, instruction, self.flags);
-		if Register::EAX as u8 <= info.op_registers[0] && info.op_registers[0] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = (info.op_registers[0].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
-		if Register::EAX as u8 <= info.op_registers[1] && info.op_registers[1] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = (info.op_registers[1].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
-		if Register::EAX as u8 <= info.op_registers[2] && info.op_registers[2] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[2] = (info.op_registers[2].wrapping_sub(Register::EAX as u8) & 0xF).wrapping_add(Register::AX as u8);
-		}
+		info.op_registers[0] = r_to_r16(info.op_registers[0]);
+		info.op_registers[1] = r_to_r16(info.op_registers[1]);
+		info.op_registers[2] = r_to_r16(info.op_registers[2]);
 		info
 	}
 }
@@ -1279,18 +1237,9 @@ impl SimpleInstrInfo_Reg32 {
 impl InstrInfo for SimpleInstrInfo_Reg32 {
 	fn op_info<'a>(&'a self, _options: &FormatterOptions, instruction: &Instruction) -> InstrOpInfo<'a> {
 		let mut info = InstrOpInfo::new(&self.mnemonic, instruction, self.flags);
-		if Register::RAX as u8 <= info.op_registers[0] && info.op_registers[0] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[0] = info.op_registers[0].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
-		if Register::RAX as u8 <= info.op_registers[1] && info.op_registers[1] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[1] = info.op_registers[1].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
-		if Register::RAX as u8 <= info.op_registers[2] && info.op_registers[2] <= Register::R15 as u8 {
-			const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-			info.op_registers[2] = info.op_registers[2].wrapping_sub(Register::RAX as u8).wrapping_add(Register::EAX as u8);
-		}
+		info.op_registers[0] = r64_to_r32(info.op_registers[0]);
+		info.op_registers[1] = r64_to_r32(info.op_registers[1]);
+		info.op_registers[2] = r64_to_r32(info.op_registers[2]);
 		info
 	}
 }
@@ -1312,8 +1261,7 @@ impl InstrInfo for SimpleInstrInfo_reg {
 		let mut info = InstrOpInfo::default(&self.mnemonic);
 		info.op_count = 1;
 		info.op_kinds[0] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[0] = self.register as u8;
+		info.op_registers[0] = self.register;
 		info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_READ;
 		info
 	}
@@ -1337,27 +1285,13 @@ impl InstrInfo for SimpleInstrInfo_invlpga {
 		info.op_count = 2;
 		info.op_kinds[0] = InstrOpKind::Register;
 		info.op_kinds[1] = InstrOpKind::Register;
-		const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-		info.op_registers[1] = Register::ECX as u8;
+		info.op_registers[1] = Register::ECX;
 		info.op_indexes[0] = InstrInfoConstants::OP_ACCESS_READ;
 		info.op_indexes[1] = InstrInfoConstants::OP_ACCESS_READ;
-
 		match self.bitness {
-			16 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::AX as u8;
-			}
-
-			32 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::EAX as u8;
-			}
-
-			64 => {
-				const_assert_eq!(InstrOpInfo::TEST_REGISTER_BITS, 8);
-				info.op_registers[0] = Register::RAX as u8;
-			}
-
+			16 => info.op_registers[0] = Register::AX,
+			32 => info.op_registers[0] = Register::EAX,
+			64 => info.op_registers[0] = Register::RAX,
 			_ => unreachable!(),
 		}
 		info
